-- Copyright 2002-2006 Spencer Olson


--
-- OrderDB schema creation script
--

\connect - owner_user

SET search_path = public, pg_catalog;


--
-- TOC entry 21 (OID 20847)
-- Name: grouprooms; Type: TABLE; Schema: public; Owner: owner_user
--

CREATE TABLE grouprooms (
    phonenumber character(16) NOT NULL,
    roomnumber character varying(32) NOT NULL
);


--
-- TOC entry 22 (OID 20847)
-- Name: grouprooms; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE grouprooms FROM PUBLIC;
GRANT SELECT ON TABLE grouprooms TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE grouprooms TO apache_admin;


--
-- TOC entry 23 (OID 20851)
-- Name: accounts; Type: TABLE; Schema: public; Owner: owner_user
--

CREATE TABLE accounts (
    accountnumber character(6) NOT NULL,
    name character varying(32) NOT NULL,
    pi oid NOT NULL,
    datecreated timestamp with time zone DEFAULT now(),
    dateclosed timestamp with time zone
);


--
-- TOC entry 24 (OID 20851)
-- Name: accounts; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE accounts FROM PUBLIC;
GRANT SELECT ON TABLE accounts TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE accounts TO apache_admin;


--
-- TOC entry 27 (OID 20860)
-- Name: shiptoaddresses; Type: TABLE; Schema: public; Owner: owner_user
--

CREATE TABLE shiptoaddresses (
    id oid NOT NULL,
    name character varying(32) NOT NULL,
    streetaddress1 character varying(50) NOT NULL,
    streetaddress2 character varying(50),
    zip character(16) NOT NULL
);


--
-- TOC entry 28 (OID 20860)
-- Name: shiptoaddresses; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE shiptoaddresses FROM PUBLIC;
GRANT SELECT ON TABLE shiptoaddresses TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE shiptoaddresses TO apache_admin;


--
-- TOC entry 29 (OID 20864)
-- Name: vendors; Type: TABLE; Schema: public; Owner: owner_user
--

CREATE TABLE vendors (
    id oid NOT NULL,
    name character varying(50) NOT NULL,
    streetaddress1 character varying(50) NOT NULL,
    streetaddress2 character varying(50),
    city character varying(32) NOT NULL,
    state character varying(32) NOT NULL,
    zip character(16) NOT NULL,
    country character varying(32) DEFAULT 'USA',
    phone character varying(32) NOT NULL,
    fax character varying(32),
    web character varying(256)
);


--
-- TOC entry 30 (OID 20864)
-- Name: vendors; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE vendors FROM PUBLIC;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE vendors TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE vendors TO apache_admin;


--
-- TOC entry 2 (OID 20869)
-- Name: personnel_id_sequence; Type: SEQUENCE; Schema: public; Owner: owner_user
--

CREATE SEQUENCE personnel_id_sequence
    START 1
    INCREMENT 1
    MAXVALUE 2147483647
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 4 (OID 20869)
-- Name: personnel_id_sequence; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE personnel_id_sequence FROM PUBLIC;
GRANT SELECT ON TABLE personnel_id_sequence TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE personnel_id_sequence TO apache_admin;


--
-- TOC entry 5 (OID 20871)
-- Name: vendors_id_sequence; Type: SEQUENCE; Schema: public; Owner: owner_user
--

CREATE SEQUENCE vendors_id_sequence
    START 1
    INCREMENT 1
    MAXVALUE 2147483647
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 7 (OID 20871)
-- Name: vendors_id_sequence; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE vendors_id_sequence FROM PUBLIC;
GRANT INSERT,SELECT,UPDATE ON TABLE vendors_id_sequence TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE vendors_id_sequence TO apache_admin;


--
-- TOC entry 8 (OID 20873)
-- Name: po_id; Type: SEQUENCE; Schema: public; Owner: owner_user
--

CREATE SEQUENCE po_id
    START 1
    INCREMENT 1
    MAXVALUE 2147483647
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 10 (OID 20873)
-- Name: po_id; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE po_id FROM PUBLIC;
GRANT SELECT,UPDATE ON TABLE po_id TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE po_id TO apache_admin;


--
-- TOC entry 31 (OID 20875)
-- Name: purchaseorders; Type: TABLE; Schema: public; Owner: owner_user
--

CREATE TABLE purchaseorders (
    id oid NOT NULL,
    orderedbyid oid NOT NULL,
    approvedby character varying(32),
    umich_contactnumber character(16) NOT NULL,
    ordereddate date NOT NULL,
    dateneeded date,
    accountnumber character(6) NOT NULL,
    shipmentmethod character varying(100) NOT NULL,
    shipmentdetails text,
    vendorid oid NOT NULL,
    shippinghandling numeric(12,2) NOT NULL,
    othercharges numeric(12,2) NOT NULL,
    shiptoid oid NOT NULL,
    vendorcontact character varying(32),
    cancelled boolean DEFAULT 'false',
    cleared boolean DEFAULT 'false',
    quote_number character varying(32)
);


--
-- TOC entry 32 (OID 20875)
-- Name: purchaseorders; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE purchaseorders FROM PUBLIC;
GRANT INSERT,SELECT,UPDATE ON TABLE purchaseorders TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE purchaseorders TO apache_admin;


--
-- TOC entry 33 (OID 20883)
-- Name: purchaseitems; Type: TABLE; Schema: public; Owner: owner_user
--

CREATE TABLE purchaseitems (
    purchaseid oid NOT NULL,
    quantity smallint NOT NULL,
    unit character varying(32) NOT NULL,
    description character varying(255) NOT NULL,
    unitprice numeric(12,2) NOT NULL
);


--
-- TOC entry 34 (OID 20883)
-- Name: purchaseitems; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE purchaseitems FROM PUBLIC;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE purchaseitems TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE purchaseitems TO apache_admin;


--
-- TOC entry 35 (OID 20885)
-- Name: personnel; Type: TABLE; Schema: public; Owner: owner_user
--

CREATE TABLE personnel (
    id oid NOT NULL,
    firstname character varying(32) NOT NULL,
    lastname character varying(32) NOT NULL,
    uniquename character varying(32) NOT NULL
);


--
-- TOC entry 36 (OID 20885)
-- Name: personnel; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE personnel FROM PUBLIC;
GRANT SELECT ON TABLE personnel TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE personnel TO apache_admin;


--
-- TOC entry 37 (OID 20889)
-- Name: account_credits; Type: TABLE; Schema: public; Owner: owner_user
--

CREATE TABLE account_credits (
    accountnumber character(6) NOT NULL,
    credit numeric(12,2) NOT NULL,
    dateapplied date NOT NULL,
    description character varying(255)
);


--
-- TOC entry 38 (OID 20889)
-- Name: account_credits; Type: ACL; Schema: public; Owner: owner_user
--

REVOKE ALL ON TABLE account_credits FROM PUBLIC;
GRANT INSERT,SELECT,UPDATE ON TABLE account_credits TO apache;
GRANT INSERT,SELECT,UPDATE ON TABLE account_credits TO apache_admin;


--
-- TOC entry 39 (OID 20849)
-- Name: grouprooms_pkey; Type: CONSTRAINT; Schema: public; Owner: owner_user
--

ALTER TABLE ONLY grouprooms
    ADD CONSTRAINT grouprooms_pkey PRIMARY KEY (phonenumber);


--
-- TOC entry 40 (OID 20853)
-- Name: accounts_pkey; Type: CONSTRAINT; Schema: public; Owner: owner_user
--

ALTER TABLE ONLY accounts
    ADD CONSTRAINT accounts_pkey PRIMARY KEY (accountnumber);


--
-- TOC entry 41 (OID 20862)
-- Name: shiptoaddresses_pkey; Type: CONSTRAINT; Schema: public; Owner: owner_user
--

ALTER TABLE ONLY shiptoaddresses
    ADD CONSTRAINT shiptoaddresses_pkey PRIMARY KEY (id);


--
-- TOC entry 42 (OID 20867)
-- Name: vendors_pkey; Type: CONSTRAINT; Schema: public; Owner: owner_user
--

ALTER TABLE ONLY vendors
    ADD CONSTRAINT vendors_pkey PRIMARY KEY (id);


--
-- TOC entry 43 (OID 20881)
-- Name: purchaseorders_pkey; Type: CONSTRAINT; Schema: public; Owner: owner_user
--

ALTER TABLE ONLY purchaseorders
    ADD CONSTRAINT purchaseorders_pkey PRIMARY KEY (id);


--
-- TOC entry 44 (OID 20887)
-- Name: personnel_pkey; Type: CONSTRAINT; Schema: public; Owner: owner_user
--

ALTER TABLE ONLY personnel
    ADD CONSTRAINT personnel_pkey PRIMARY KEY (id);


--
-- TOC entry 3 (OID 20869)
-- Name: personnel_id_sequence; Type: SEQUENCE SET; Schema: public; Owner: owner_user
--

SELECT pg_catalog.setval ('personnel_id_sequence', 0, true);


--
-- TOC entry 6 (OID 20871)
-- Name: vendors_id_sequence; Type: SEQUENCE SET; Schema: public; Owner: owner_user
--

SELECT pg_catalog.setval ('vendors_id_sequence', 0, true);


--
-- TOC entry 9 (OID 20873)
-- Name: po_id; Type: SEQUENCE SET; Schema: public; Owner: owner_user
--

SELECT pg_catalog.setval ('po_id', 0, true);


